netapp_ontap.models.port_statistics_device API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.port_statistics_device`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PortStatisticsDeviceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PortStatisticsDevice object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `link_down_count_raw: Size GET`

    The number of link state changes from up to down seen on the device.

    Example: 3

  `receive_raw: PortStatisticsPacketCounters GET`

    These are raw packet-related counters for the Ethernet port.

  `timestamp: ImpreciseDateTime GET`

    The timestamp when the device specific counters were collected.

    Example: 2017-01-25T11:20:13.000+0000

  `transmit_raw: PortStatisticsPacketCounters GET`

    These are raw packet-related counters for the Ethernet port.